#!/usr/bin/env ruby
# encoding: UTF-8

=begin
Copyright 2010 Vincent Carmona
vinc4mai@gmail.com

This file is part of rghk.

    rghk is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    rghk is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with rghk; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
=end

require 'mkmf'

have_header('ruby.h') or exit 1

have_library('gdk-x11-2.0', 'gdk_get_default_root_window') or exit 1
have_library('gdk-x11-2.0', 'gdk_window_add_filter') or exit 1
$CFLAGS+=`pkg-config --cflags gtk+-2.0`.chomp!
have_header('gdk/gdkevents.h') or exit 1
have_header('gdk/gdkx.h') or exit 1
have_header('X11/Xlib.h') or exit 1

create_makefile("globalhotkeys")
